==> sqldelight-oracle-dialect-0.0.12-sources.jar: app/softwork/sqldelight/oracledialect/grammar/psi/OracleTypes.java <==
// This is a generated file. Not intended for manual editing.
package app.softwork.sqldelight.oracledialect.grammar.psi;

import com.intellij.psi.tree.IElementType;
import com.intellij.psi.PsiElement;
import com.intellij.lang.ASTNode;
import com.alecstrong.sql.psi.core.SqlElementType;
import app.softwork.sqldelight.oracledialect.grammar.psi.impl.*;

public interface OracleTypes {

  IElementType ALTER_TABLESPACE = new SqlElementType("ALTER_TABLESPACE");
  IElementType APPROXIMATE_NUMERIC_DATA_TYPE = new SqlElementType("APPROXIMATE_NUMERIC_DATA_TYPE");
  IElementType BIG_INT_DATA_TYPE = new SqlElementType("BIG_INT_DATA_TYPE");
  IElementType BINARY_LARGE_OBJECT_STRING_DATA_TYPE = new SqlElementType("BINARY_LARGE_OBJECT_STRING_DATA_TYPE");
  IElementType BINARY_STRING_DATA_TYPE = new SqlElementType("BINARY_STRING_DATA_TYPE");
  IElementType BIND_PARAMETER = new SqlElementType("BIND_PARAMETER");
  IElementType BIT_STRING_DATA_TYPE = new SqlElementType("BIT_STRING_DATA_TYPE");
  IElementType BOOLEAN_DATA_TYPE = new SqlElementType("BOOLEAN_DATA_TYPE");
  IElementType CHARACTER_LARGE_OBJECT_DATA_TYPE = new SqlElementType("CHARACTER_LARGE_OBJECT_DATA_TYPE");
  IElementType CHARACTER_LARGE_OBJECT_LENGTH = new SqlElementType("CHARACTER_LARGE_OBJECT_LENGTH");
  IElementType CHARACTER_STRING_DATA_TYPE = new SqlElementType("CHARACTER_STRING_DATA_TYPE");
  IElementType CHAR_LENGTH_UNITS = new SqlElementType("CHAR_LENGTH_UNITS");
  IElementType CREATE_USER = new SqlElementType("CREATE_USER");
  IElementType DATE_DATA_TYPE = new SqlElementType("DATE_DATA_TYPE");
  IElementType DEFAULT_CONSTRAINT = new SqlElementType("DEFAULT_CONSTRAINT");
  IElementType END_FIELD = new SqlElementType("END_FIELD");
  IElementType EXTENSION_STMT = new SqlElementType("EXTENSION_STMT");
  IElementType FIXED_POINT_DATA_TYPE = new SqlElementType("FIXED_POINT_DATA_TYPE");
  IElementType GENERATED_CLAUSE = new SqlElementType("GENERATED_CLAUSE");
  IElementType GRANT_SESSION = new SqlElementType("GRANT_SESSION");
  IElementType GRANT_TABLE = new SqlElementType("GRANT_TABLE");
  IElementType INTERVAL_DATA_TYPE = new SqlElementType("INTERVAL_DATA_TYPE");
  IElementType INTERVAL_QUALIFIER = new SqlElementType("INTERVAL_QUALIFIER");
  IElementType INT_DATA_TYPE = new SqlElementType("INT_DATA_TYPE");
  IElementType LITERAL_VALUE = new SqlElementType("LITERAL_VALUE");
  IElementType MULTIPLIER = new SqlElementType("MULTIPLIER");
  IElementType NON_SECOND_PRIMARY_DATETIME_FIELD = new SqlElementType("NON_SECOND_PRIMARY_DATETIME_FIELD");
  IElementType OVERRIDES_REAL = new SqlElementType("OVERRIDES_REAL");
  IElementType PRECISION = new SqlElementType("PRECISION");
  IElementType SCALE = new SqlElementType("SCALE");
  IElementType SINGLE_DATETIME_FIELD = new SqlElementType("SINGLE_DATETIME_FIELD");
  IElementType SMALL_INT_DATA_TYPE = new SqlElementType("SMALL_INT_DATA_TYPE");
  IElementType START_FIELD = new SqlElementType("START_FIELD");
  IElementType TYPE_NAME = new SqlElementType("TYPE_NAME");

  IElementType ALTER = new IElementType("ALTER", null);
  IElementType ALWAYS = new IElementType("ALWAYS", null);
  IElementType AS = new IElementType("AS", null);
  IElementType BY = new IElementType("BY", null);
  IElementType COMMA = new IElementType("COMMA", null);
  IElementType CREATE = new IElementType("CREATE", null);
  IElementType CURRENT_DATE = new IElementType("CURRENT_DATE", null);
  IElementType CURRENT_TIMESTAMP = new IElementType("CURRENT_TIMESTAMP", null);
  IElementType DEFAULT = new IElementType("DEFAULT", null);
  IElementType DELETE = new IElementType("DELETE", null);
  IElementType DIGIT = new IElementType("digit", null);
  IElementType ELEMENTTYPE = new IElementType("elementType", null);
  IElementType GENERATED = new IElementType("GENERATED", null);
  IElementType INSERT = new IElementType("INSERT", null);
  IElementType LP = new IElementType("LP", null);
  IElementType NULL = new IElementType("NULL", null);
  IElementType ON = new IElementType("ON", null);
  IElementType RP = new IElementType("RP", null);
  IElementType SELECT = new IElementType("SELECT", null);
  IElementType TABLE = new IElementType("TABLE", null);
  IElementType TO = new IElementType("TO", null);
  IElementType UPDATE = new IElementType("UPDATE", null);
  IElementType VIEW = new IElementType("VIEW", null);
  IElementType WITH = new IElementType("WITH", null);
  IElementType WITHOUT = new IElementType("WITHOUT", null);

  class Factory {
    public static PsiElement createElement(ASTNode node) {
      IElementType type = node.getElementType();
      if (type == ALTER_TABLESPACE) {
        return new OracleAlterTablespaceImpl(node);
      }
      else if (type == APPROXIMATE_NUMERIC_DATA_TYPE) {
        return new OracleApproximateNumericDataTypeImpl(node);
      }
      else if (type == BIG_INT_DATA_TYPE) {
        return new OracleBigIntDataTypeImpl(node);
      }
      else if (type == BINARY_LARGE_OBJECT_STRING_DATA_TYPE) {
        return new OracleBinaryLargeObjectStringDataTypeImpl(node);
      }
      else if (type == BINARY_STRING_DATA_TYPE) {
        return new OracleBinaryStringDataTypeImpl(node);
      }
      else if (type == BIND_PARAMETER) {
        return new OracleBindParameterImpl(node);
      }
      else if (type == BIT_STRING_DATA_TYPE) {
        return new OracleBitStringDataTypeImpl(node);
      }
      else if (type == BOOLEAN_DATA_TYPE) {
        return new OracleBooleanDataTypeImpl(node);
      }
      else if (type == CHARACTER_LARGE_OBJECT_DATA_TYPE) {
        return new OracleCharacterLargeObjectDataTypeImpl(node);
      }
      else if (type == CHARACTER_LARGE_OBJECT_LENGTH) {
        return new OracleCharacterLargeObjectLengthImpl(node);
      }
      else if (type == CHARACTER_STRING_DATA_TYPE) {
        return new OracleCharacterStringDataTypeImpl(node);
      }
      else if (type == CHAR_LENGTH_UNITS) {
        return new OracleCharLengthUnitsImpl(node);
      }
      else if (type == CREATE_USER) {
        return new OracleCreateUserImpl(node);
      }
      else if (type == DATE_DATA_TYPE) {
        return new OracleDateDataTypeImpl(node);
      }
      else if (type == DEFAULT_CONSTRAINT) {
        return new OracleDefaultConstraintImpl(node);
      }
      else if (type == END_FIELD) {
        return new OracleEndFieldImpl(node);
      }
      else if (type == EXTENSION_STMT) {
        return new OracleExtensionStmtImpl(node);
      }
      else if (type == FIXED_POINT_DATA_TYPE) {
        return new OracleFixedPointDataTypeImpl(node);
      }
      else if (type == GENERATED_CLAUSE) {
        return new OracleGeneratedClauseImpl(node);
      }
      else if (type == GRANT_SESSION) {
        return new OracleGrantSessionImpl(node);
      }
      else if (type == GRANT_TABLE) {
        return new OracleGrantTableImpl(node);
      }
      else if (type == INTERVAL_DATA_TYPE) {
        return new OracleIntervalDataTypeImpl(node);
      }
      else if (type == INTERVAL_QUALIFIER) {
        return new OracleIntervalQualifierImpl(node);
      }
      else if (type == INT_DATA_TYPE) {
        return new OracleIntDataTypeImpl(node);
      }
      else if (type == LITERAL_VALUE) {
        return new OracleLiteralValueImpl(node);
      }
      else if (type == MULTIPLIER) {
        return new OracleMultiplierImpl(node);
      }
      else if (type == NON_SECOND_PRIMARY_DATETIME_FIELD) {
        return new OracleNonSecondPrimaryDatetimeFieldImpl(node);
      }
      else if (type == OVERRIDES_REAL) {
        return new OracleOverridesRealImpl(node);
      }
      else if (type == PRECISION) {
        return new OraclePrecisionImpl(node);
      }
      else if (type == SCALE) {
        return new OracleScaleImpl(node);
      }
      else if (type == SINGLE_DATETIME_FIELD) {
        return new OracleSingleDatetimeFieldImpl(node);
      }
      else if (type == SMALL_INT_DATA_TYPE) {
        return new OracleSmallIntDataTypeImpl(node);
      }
      else if (type == START_FIELD) {
        return new OracleStartFieldImpl(node);
      }
      else if (type == TYPE_NAME) {
        return new OracleTypeNameImpl(node);
      }
      throw new AssertionError("Unknown element type: " + type);
    }
  }
}

==> sqldelight-oracle-dialect-0.0.15-sources.jar: app/softwork/sqldelight/oracledialect/grammar/psi/OracleTypes.java <==
// This is a generated file. Not intended for manual editing.
package app.softwork.sqldelight.oracledialect.grammar.psi;

import com.intellij.psi.tree.IElementType;
import com.intellij.psi.PsiElement;
import com.intellij.lang.ASTNode;
import com.alecstrong.sql.psi.core.SqlElementType;
import app.softwork.sqldelight.oracledialect.grammar.psi.impl.*;

public interface OracleTypes {

  IElementType ALTER_TABLESPACE_REAL = new SqlElementType("ALTER_TABLESPACE_REAL");
  IElementType APPROXIMATE_NUMERIC_DATA_TYPE = new SqlElementType("APPROXIMATE_NUMERIC_DATA_TYPE");
  IElementType BIG_INT_DATA_TYPE = new SqlElementType("BIG_INT_DATA_TYPE");
  IElementType BINARY_LARGE_OBJECT_STRING_DATA_TYPE = new SqlElementType("BINARY_LARGE_OBJECT_STRING_DATA_TYPE");
  IElementType BINARY_STRING_DATA_TYPE = new SqlElementType("BINARY_STRING_DATA_TYPE");
  IElementType BIND_PARAMETER = new SqlElementType("BIND_PARAMETER");
  IElementType BIT_STRING_DATA_TYPE = new SqlElementType("BIT_STRING_DATA_TYPE");
  IElementType BOOLEAN_DATA_TYPE = new SqlElementType("BOOLEAN_DATA_TYPE");
  IElementType CHARACTER_LARGE_OBJECT_DATA_TYPE = new SqlElementType("CHARACTER_LARGE_OBJECT_DATA_TYPE");
  IElementType CHARACTER_LARGE_OBJECT_LENGTH = new SqlElementType("CHARACTER_LARGE_OBJECT_LENGTH");
  IElementType CHARACTER_STRING_DATA_TYPE = new SqlElementType("CHARACTER_STRING_DATA_TYPE");
  IElementType CHAR_LENGTH_UNITS = new SqlElementType("CHAR_LENGTH_UNITS");
  IElementType CREATE_USER = new SqlElementType("CREATE_USER");
  IElementType DATE_DATA_TYPE = new SqlElementType("DATE_DATA_TYPE");
  IElementType DEFAULT_CONSTRAINT = new SqlElementType("DEFAULT_CONSTRAINT");
  IElementType END_FIELD = new SqlElementType("END_FIELD");
  IElementType EXTENSION_STMT = new SqlElementType("EXTENSION_STMT");
  IElementType FIXED_POINT_DATA_TYPE = new SqlElementType("FIXED_POINT_DATA_TYPE");
  IElementType GENERATED_CLAUSE = new SqlElementType("GENERATED_CLAUSE");
  IElementType GRANT_SESSION = new SqlElementType("GRANT_SESSION");
  IElementType GRANT_TABLE = new SqlElementType("GRANT_TABLE");
  IElementType INTERVAL_DATA_TYPE = new SqlElementType("INTERVAL_DATA_TYPE");
  IElementType INTERVAL_QUALIFIER = new SqlElementType("INTERVAL_QUALIFIER");
  IElementType INT_DATA_TYPE = new SqlElementType("INT_DATA_TYPE");
  IElementType LITERAL_VALUE = new SqlElementType("LITERAL_VALUE");
  IElementType MERGE = new SqlElementType("MERGE");
  IElementType MERGE_INSERT_CLAUSE = new SqlElementType("MERGE_INSERT_CLAUSE");
  IElementType MERGE_ON = new SqlElementType("MERGE_ON");
  IElementType MERGE_UPDATE_CLAUSE = new SqlElementType("MERGE_UPDATE_CLAUSE");
  IElementType MERGE_UPDATE_COLUMN_CLAUSE = new SqlElementType("MERGE_UPDATE_COLUMN_CLAUSE");
  IElementType MERGE_UPDATE_COLUMN_CLAUSE_SINGLE = new SqlElementType("MERGE_UPDATE_COLUMN_CLAUSE_SINGLE");
  IElementType MULTIPLIER = new SqlElementType("MULTIPLIER");
  IElementType NON_SECOND_PRIMARY_DATETIME_FIELD = new SqlElementType("NON_SECOND_PRIMARY_DATETIME_FIELD");
  IElementType OVERRIDES_REAL = new SqlElementType("OVERRIDES_REAL");
  IElementType PRECISION = new SqlElementType("PRECISION");
  IElementType SCALE = new SqlElementType("SCALE");
  IElementType SINGLE_DATETIME_FIELD = new SqlElementType("SINGLE_DATETIME_FIELD");
  IElementType SMALL_INT_DATA_TYPE = new SqlElementType("SMALL_INT_DATA_TYPE");
  IElementType START_FIELD = new SqlElementType("START_FIELD");
  IElementType TYPE_NAME = new SqlElementType("TYPE_NAME");

  IElementType ALTER = new IElementType("ALTER", null);
  IElementType ALWAYS = new IElementType("ALWAYS", null);
  IElementType AS = new IElementType("AS", null);
  IElementType BY = new IElementType("BY", null);
  IElementType COMMA = new IElementType("COMMA", null);
  IElementType CREATE = new IElementType("CREATE", null);
  IElementType CURRENT_DATE = new IElementType("CURRENT_DATE", null);
  IElementType CURRENT_TIMESTAMP = new IElementType("CURRENT_TIMESTAMP", null);
  IElementType DEFAULT = new IElementType("DEFAULT", null);
  IElementType DELETE = new IElementType("DELETE", null);
  IElementType DIGIT = new IElementType("digit", null);
  IElementType DOT = new IElementType("DOT", null);
  IElementType ELEMENTTYPE = new IElementType("elementType", null);
  IElementType EQ = new IElementType("EQ", null);
  IElementType GENERATED = new IElementType("GENERATED", null);
  IElementType INSERT = new IElementType("INSERT", null);
  IElementType INTO = new IElementType("INTO", null);
  IElementType LP = new IElementType("LP", null);
  IElementType NOT = new IElementType("NOT", null);
  IElementType NULL = new IElementType("NULL", null);
  IElementType ON = new IElementType("ON", null);
  IElementType RP = new IElementType("RP", null);
  IElementType SELECT = new IElementType("SELECT", null);
  IElementType SET = new IElementType("SET", null);
  IElementType TABLE = new IElementType("TABLE", null);
  IElementType THEN = new IElementType("THEN", null);
  IElementType TO = new IElementType("TO", null);
  IElementType UPDATE = new IElementType("UPDATE", null);
  IElementType USING = new IElementType("USING", null);
  IElementType VIEW = new IElementType("VIEW", null);
  IElementType WHEN = new IElementType("WHEN", null);
  IElementType WHERE = new IElementType("WHERE", null);
  IElementType WITH = new IElementType("WITH", null);
  IElementType WITHOUT = new IElementType("WITHOUT", null);

  class Factory {
    public static PsiElement createElement(ASTNode node) {
      IElementType type = node.getElementType();
      if (type == ALTER_TABLESPACE_REAL) {
        return new OracleAlterTablespaceRealImpl(node);
      }
      else if (type == APPROXIMATE_NUMERIC_DATA_TYPE) {
        return new OracleApproximateNumericDataTypeImpl(node);
      }
      else if (type == BIG_INT_DATA_TYPE) {
        return new OracleBigIntDataTypeImpl(node);
      }
      else if (type == BINARY_LARGE_OBJECT_STRING_DATA_TYPE) {
        return new OracleBinaryLargeObjectStringDataTypeImpl(node);
      }
      else if (type == BINARY_STRING_DATA_TYPE) {
        return new OracleBinaryStringDataTypeImpl(node);
      }
      else if (type == BIND_PARAMETER) {
        return new OracleBindParameterImpl(node);
      }
      else if (type == BIT_STRING_DATA_TYPE) {
        return new OracleBitStringDataTypeImpl(node);
      }
      else if (type == BOOLEAN_DATA_TYPE) {
        return new OracleBooleanDataTypeImpl(node);
      }
      else if (type == CHARACTER_LARGE_OBJECT_DATA_TYPE) {
        return new OracleCharacterLargeObjectDataTypeImpl(node);
      }
      else if (type == CHARACTER_LARGE_OBJECT_LENGTH) {
        return new OracleCharacterLargeObjectLengthImpl(node);
      }
      else if (type == CHARACTER_STRING_DATA_TYPE) {
        return new OracleCharacterStringDataTypeImpl(node);
      }
      else if (type == CHAR_LENGTH_UNITS) {
        return new OracleCharLengthUnitsImpl(node);
      }
      else if (type == CREATE_USER) {
        return new OracleCreateUserImpl(node);
      }
      else if (type == DATE_DATA_TYPE) {
        return new OracleDateDataTypeImpl(node);
      }
      else if (type == DEFAULT_CONSTRAINT) {
        return new OracleDefaultConstraintImpl(node);
      }
      else if (type == END_FIELD) {
        return new OracleEndFieldImpl(node);
      }
      else if (type == EXTENSION_STMT) {
        return new OracleExtensionStmtImpl(node);
      }
      else if (type == FIXED_POINT_DATA_TYPE) {
        return new OracleFixedPointDataTypeImpl(node);
      }
      else if (type == GENERATED_CLAUSE) {
        return new OracleGeneratedClauseImpl(node);
      }
      else if (type == GRANT_SESSION) {
        return new OracleGrantSessionImpl(node);
      }
      else if (type == GRANT_TABLE) {
        return new OracleGrantTableImpl(node);
      }
      else if (type == INTERVAL_DATA_TYPE) {
        return new OracleIntervalDataTypeImpl(node);
      }
      else if (type == INTERVAL_QUALIFIER) {
        return new OracleIntervalQualifierImpl(node);
      }
      else if (type == INT_DATA_TYPE) {
        return new OracleIntDataTypeImpl(node);
      }
      else if (type == LITERAL_VALUE) {
        return new OracleLiteralValueImpl(node);
      }
      else if (type == MERGE) {
        return new OracleMergeImpl(node);
      }
      else if (type == MERGE_INSERT_CLAUSE) {
        return new OracleMergeInsertClauseImpl(node);
      }
      else if (type == MERGE_ON) {
        return new OracleMergeOnImpl(node);
      }
      else if (type == MERGE_UPDATE_CLAUSE) {
        return new OracleMergeUpdateClauseImpl(node);
      }
      else if (type == MERGE_UPDATE_COLUMN_CLAUSE) {
        return new OracleMergeUpdateColumnClauseImpl(node);
      }
      else if (type == MERGE_UPDATE_COLUMN_CLAUSE_SINGLE) {
        return new OracleMergeUpdateColumnClauseSingleImpl(node);
      }
      else if (type == MULTIPLIER) {
        return new OracleMultiplierImpl(node);
      }
      else if (type == NON_SECOND_PRIMARY_DATETIME_FIELD) {
        return new OracleNonSecondPrimaryDatetimeFieldImpl(node);
      }
      else if (type == OVERRIDES_REAL) {
        return new OracleOverridesRealImpl(node);
      }
      else if (type == PRECISION) {
        return new OraclePrecisionImpl(node);
      }
      else if (type == SCALE) {
        return new OracleScaleImpl(node);
      }
      else if (type == SINGLE_DATETIME_FIELD) {
        return new OracleSingleDatetimeFieldImpl(node);
      }
      else if (type == SMALL_INT_DATA_TYPE) {
        return new OracleSmallIntDataTypeImpl(node);
      }
      else if (type == START_FIELD) {
        return new OracleStartFieldImpl(node);
      }
      else if (type == TYPE_NAME) {
        return new OracleTypeNameImpl(node);
      }
      throw new AssertionError("Unknown element type: " + type);
    }
  }
}
